@@ -9,6 +9,7 @@ from django.utils.functional import cached_property
 from django.utils.text import slugify
 from django_geosource.models import Source, Field
 from rest_framework.reverse import reverse
+from mapbox_baselayer.models import MapBaseLayer
 
 from .utils import get_layer_group_cache_key
 from .schema import JSONSchemaValidator, SCENE_LAYERTREE
@@ -31,6 +32,7 @@ class Scene(models.Model):
         default=list, validators=[JSONSchemaValidator(limit_value=SCENE_LAYERTREE)]
     )
     config = JSONField(default=dict)
+    baselayer = models.ManyToManyField(MapBaseLayer)
 
     def get_absolute_url(self):
         return reverse("scene-detail", args=[self.pk])
@@ -166,15 +168,9 @@ class Layer(models.Model):
     table_enable = models.BooleanField(default=False)
     table_export_enable = models.BooleanField(default=False)
 
-    popup_enable = models.BooleanField(default=False)
-    popup_template = models.TextField(blank=True)
-    popup_minzoom = models.FloatField(default=0)
-    popup_maxzoom = models.FloatField(default=22)
+    popup_config = JSONField(default=dict)
+    minisheet_config = JSONField(default=dict)
 
-    minisheet_enable = models.BooleanField(default=False)
-    minisheet_template = models.TextField(blank=True)
-
-    highlight_color = models.CharField(max_length=255, blank=True)
     main_field = models.ForeignKey(
         Field, null=True, on_delete=models.CASCADE, related_name="is_main_of"
     )
