@@ -1,6 +1,6 @@
 import factory
 
-from ..models import Scene
+from ..models import Scene, Layer
 
 
 class SceneFactory(factory.django.DjangoModelFactory):
@@ -8,3 +8,8 @@ class SceneFactory(factory.django.DjangoModelFactory):
         model = Scene
 
     custom_icon = factory.django.ImageField()
+
+
+class LayerFactory(factory.django.DjangoModelFactory):
+    class Meta:
+        model = Layer
