@@ -1,4 +1,5 @@
 import tempfile
+from copy import deepcopy
 
 from django.core.management import call_command, get_commands
 from django.conf import settings
@@ -84,13 +85,11 @@ class SceneViewset(ModelViewSet):
                 call_command("load_xls", scene_name=scene_name, file=xls_file.name)
 
     def perform_update(self, serializer):
-
         if serializer.is_valid():
             self.check_layer_status(
                 serializer.instance.id, serializer.validated_data.get("tree", [])
             )
             serializer.save()
-
         self.handle_import_file(serializer.instance.name)
 
     def perform_create(self, serializer):
@@ -117,8 +116,6 @@ class LayerViewset(ModelViewSet):
         "active_by_default",
         "in_tree",
         "table_enable",
-        "popup_enable",
-        "minisheet_enable",
     )
     permission_classes = (LayerPermission,)
     search_fields = ["name", "settings"]
@@ -231,7 +228,7 @@ class LayerView(APIView):
 
     def get_layer_structure(self):
         """Return the structured layerTree"""
-        return {
+        layer_structure = {
             "title": self.scene.name,
             "type": self.scene.category,
             "layersTree": self.get_layers_tree(self.scene),
@@ -242,6 +239,28 @@ class LayerView(APIView):
             },
         }
 
+        # settings are merged for now
+        baselayers = [
+            {
+                "label": baselayer.name,
+                "url": baselayer.url,
+            }
+            for baselayer in self.scene.baselayer.all()
+        ]
+
+        # avoid futur reference modifications
+        map_structure = deepcopy(layer_structure["map"])
+        background_styles = map_structure.get("backgroundStyle", [])
+
+        if type(background_styles) is list:
+            background_styles += baselayers
+        else:
+            # backgroundStyles can be just an url
+            baselayers.append({"label": "terra_default", "url": background_styles})
+            background_styles = baselayers
+        layer_structure["map"]["backgroundStyle"] = background_styles
+        return layer_structure
+
     def get_map_layers(self):
         """Return sources informations using serializer from sources_serializers module"""
         map_layers = []
@@ -296,7 +315,7 @@ class LayerView(APIView):
 
         main_field = getattr(layer.main_field, "name", None)
 
-        if layer.popup_enable:
+        if layer.popup_config.get("enable"):
             interactions.append(
                 {
                     "id": layer.layer_identifier,
@@ -304,20 +323,23 @@ class LayerView(APIView):
                     "clusterLabel": main_field,  # Kept for compatibility purpose
                     "interaction": "displayTooltip",
                     "trigger": "mouseover",
-                    "template": layer.popup_template,
+                    "template": layer.popup_config.get("template"),
                     "constraints": [
-                        {"minZoom": layer.popup_minzoom, "maxZoom": layer.popup_maxzoom}
+                        {
+                            "minZoom": layer.popup_config.get("minzoom"),
+                            "maxZoom": layer.popup_config.get("maxzoom"),
+                        },
                     ],
                 }
             )
 
-        if layer.minisheet_enable:
+        if layer.minisheet_config.get("enable"):
             settings_interactions = {
                 "id": layer.layer_identifier,
                 "mainField": main_field,
                 "clusterLabel": main_field,  # Kept for compatibility purpose
                 "interaction": "displayDetails",
-                "template": layer.minisheet_template,
+                "template": layer.minisheet_config.get("template", ""),
                 "fetchProperties": {
                     "url": urlunquote(
                         reverse(
@@ -328,8 +350,10 @@ class LayerView(APIView):
                     "id": "_id",
                 },
             }
-            if layer.highlight_color:
-                settings_interactions["highlight_color"] = layer.highlight_color
+            if layer.minisheet_config.get("highlight_color"):
+                settings_interactions["highlight_color"] = layer.minisheet_config[
+                    "highlight_color"
+                ]
 
             interactions.append(settings_interactions)
 
